# Neural networks

::: sbi.neural_nets.factory.posterior_nn

::: sbi.neural_nets.factory.likelihood_nn

::: sbi.neural_nets.factory.classifier_nn

::: sbi.neural_nets.factory.flowmatching_nn

::: sbi.neural_nets.factory.posterior_score_nn

::: sbi.neural_nets.estimators.ConditionalDensityEstimator
